@@ -21,7 +21,7 @@
 
 import sys
 import os
-
+from importlib import import_module
 
 def get_root_path(import_name: str) -> str:
     """
@@ -35,3 +35,24 @@ def get_root_path(import_name: str) -> str:
 
     if module is not None and hasattr(module, "__file__"):
         return os.path.dirname(os.path.realpath(module.__file__))
+
+def import_string(module: str):
+    """
+    Import the given module path.
+    """
+
+    try:
+        _module, func = module.strip(' ').rsplit('.', 1)
+
+    except ValueError:
+        raise ImportError('It looks like module {} is not a valid module'.format(module))
+
+
+    mod = import_module(_module)
+    
+    try:
+        return (mod, getattr(mod, func))
+    except AttributeError:
+        # TODO: NO ATTRIBUTE
+        raise ImportError('Module has no attribute: %s' % (func))
+    
\ No newline at end of file
